# Example Package

This program automatically downloads the json file from the public database
https://data.nasa.gov/Applied-Science/Outgassing-Db/r588-f7pr
(located in https://data.nasa.gov/resource/r588-f7pr.json)
and generates some statistics for the variable total mass loss (tml):
- Prints on terminal tml min, max and mean
- Plot a boxplot for the first two elements with more samples